==> nextcloud-32.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/user_ldap/l10n/he.js <==
OC.L10N.register(
    "user_ldap",
    {
    "Failed to clear the mappings." : "כשל בניקוי המיפויים.",
    "Failed to delete the server configuration" : "כשל במחיקת הגדרות השרת",
    "Invalid configuration: Anonymous binding is not allowed." : "תצורה שגויה: איגוד אלמוני אסור.",
    "Valid configuration, connection established!" : "התצורה תקפה, התבצע חיבור!",
    "Valid configuration, but binding failed. Please check the server settings and credentials." : "התצורה תקפה, אך האיגוד נכשל. נא לבדוק את הגדרות השרת ואת פרטי הגישה.",
    "No action specified" : "לא צויינה פעולה",
    "No configuration specified" : "לא הוגדרה תצורה",
    "No data specified" : "לא הוגדר מידע",
    "Action does not exist" : "פעולה לא קיימת",
    "Renewing …" : "מתבצע חידוש…",
    "Very weak password" : "ססמה חלשה מאוד",
    "Weak password" : "ססמה חלשה",
    "So-so password" : "ססמה בסדר",
    "Good password" : "ססמה טובה",
    "Strong password" : "ססמה חזקה",
    "The Base DN appears to be wrong" : "בסיס DN נראה כשגוי",
    "Testing configuration…" : "בדיקת תצורה...",
    "Configuration incorrect" : "הגדרה שגויה",
    "Configuration incomplete" : "הגדרה לא מלאה",
    "Configuration OK" : "הגדרה בסדר",
    "Select groups" : "בחירת קבוצות",
    "Select object classes" : "בחירת מחלקות עצמים",
    "Please check the credentials, they seem to be wrong." : "יש לבדוק את פרטי הכניסה, נראה שהם שגויים",
    "Please specify the port, it could not be auto-detected." : "יש לספק את שער הכניסה - פורט, לא ניתן היה לאתרו בצורה אוטומטית",
    "Base DN could not be auto-detected, please revise credentials, host and port." : "לא ניתן היה לאתר באופן אוטומטי את בסיס DN, יש להחליף את פרטי הכניסה, פרטי שרת ושער גישה - פורט.",
    "Could not detect Base DN, please enter it manually." : "לא ניתן היה לאתר את בסיס DN, יש להכניסו באופן ידני.",
    "{nthServer}. Server" : "{nthServer}. שרת",
    "No object found in the given Base DN. Please revise." : "לא אותר אוביקט בבסיס DN שסופק. יש להחליף.",
    "More than 1,000 directory entries available." : "קיימים יותר מ- 1,000 רשומות ספריה.",
    "An error occurred. Please check the Base DN, as well as connection settings and credentials." : "אירעה שגיאה. יש לבדוק את בסיס ה- DN, כמו גם את הגדרות החיבור ופרטי הכניסה.",
    "Do you really want to delete the current Server Configuration?" : "האם אכן למחוק את הגדרות השרת הנוכחיות?האם באמת ברצונך למחוק את הגדרות השרת הנוכחיות?",
    "Confirm Deletion" : "אישור המחיקה",
    "Mappings cleared successfully!" : "מיפויים נוקו בהצלחה!",
    "Error while clearing the mappings." : "שגיאה בזמן ניקוי המיפויים.",
    "Anonymous bind is not allowed. Please provide a User DN and Password." : "קישור אננונימי אינו מותר. יש לספק שם משתמש DN וסיסמא.",
    "LDAP Operations error. Anonymous bind might not be allowed." : "שגיאת פעילויות LDAP. יתכן שקישור אנונימי אינו מותר.",
    "Saving failed. Please make sure the database is in Operation. Reload before continuing." : "שמירה נכשלה. יש לבדוק אם מסד הנתונים פעיל. יש לטעון מחדש לפני המשך.",
    "Switching the mode will enable automatic LDAP queries. Depending on your LDAP size they may take a while. Do you still want to switch the mode?" : "שינוי המצב יאפשר שאילתות LDAP אוטמטיות. בהתאם לגודל ה- LDAP שלך ייתכן והפעולה תיקח זמן רב. האם ברצונך לשנות את המצב?",
    "Mode switch" : "שינוי מצב",
    "Select attributes" : "בחירת מאפיינים",
    "User found and settings verified." : "משתמש אותר והגדרות אומתו.",
    "Consider narrowing your search, as it encompassed many users, only the first one of whom will be able to log in." : "מוטב לשקול לצמצם את החיפוש שלך, כיוון שהוא מאגד בתוכו משתמשים רבים, רק הראשון מביניהם יוכל להיכנס.",
    "An unspecified error occurred. Please check log and settings." : "אירעה שגיאה בלתי מוגדרת. נא לבדוק את יומן הרישום וההגדרות.",
    "The search filter is invalid, probably due to syntax issues like uneven number of opened and closed brackets. Please revise." : "סינון החיפוש אינו חוקי. ככל הנראה בשל שיאה תחבירית כגון מספר לא שווה של פתח-סוגריים וסגור-סוגריים. יש לתקן.",
    "Please provide a login name to test against" : "יש לספק שם משתמש לבדיקה מולו",
    "Please login with the new password" : "נא להיכנס עם הססמה החדשה",
    "Your password will expire tomorrow." : "הססמה שלך תפוג מחר.",
    "Your password will expire today." : "הססמה שלך תפוג היום.",
    "_Your password will expire within %n day._::_Your password will expire within %n days._" : ["הססמה שלך תפוג בעוד יום.","הססמה שלך תפוג בעוד יומיים.","הססמה שלך תפוג בעוד %n ימים."],
    "Could not detect user display name attribute. Please specify it yourself in advanced LDAP settings." : "לא ניתן לאתר את מאפיין שם תצוגת המשתמש. נא לציין אותו בעצמך בהגדרות ה־LDAP המתקדמות.",
    "Could not find the desired feature" : "לא אותרה התכונה הרצויה",
    "Invalid Host" : "מארח לא חוקי",
    "LDAP user and group backend" : "מנגנון משתמשים וקבוצות מול LDAP",
    "This application enables administrators to connect Nextcloud to an LDAP-based user directory." : "יישומון זה מאפשר למנהלים להתחבר את Nextcloud לספריית משתמשים מבוססת LDAP.",
    "Test Configuration" : "בדיקת הגדרות",
    "Help" : "עזרה",
    "Groups meeting these criteria are available in %s:" : "קבוצות העומדות בקריטריון זה זמינות ב- %s:",
    "Only these object classes:" : "מחלקות עצמים אלו בלבד:",
    "Only from these groups:" : "רק מקבוצות אלו:",
    "Search groups" : "חיפוש בקבוצות",
    "Available groups" : "קבוצות זמינות",
    "Selected groups" : "קבוצות נבחרות",
    "Edit LDAP Query" : "עריכת שאילתת LDAP",
    "LDAP Filter:" : "מסנן LDAP:",
    "The filter specifies which LDAP groups shall have access to the %s instance." : "המסנן הקובע לאיזו קבוצת LDAP תהיה יכולת כניסה למקרה %s.",
    "Verify settings and count the groups" : "אימות ההגדרות וספירת הקבוצות",
    "When logging in, %s will find the user based on the following attributes:" : "כאשר מתחברים, %s יחפש את המשתמש על פי המאפיינים הבאים:",
    "Other Attributes:" : "מאפיינים נוספים:",
    "Test Loginname" : "בדיקת שם התחברות",
    "Verify settings" : "מאמת הגדרות",
    "%s. Server:" : "%s. שרת:",
    "Add a new configuration" : "הוספת תצורה חדשה",
    "Copy current configuration into new directory binding" : "מעתיק תצורה נוכחית אל תוך תיקייה חדשה",
    "Delete the current configuration" : "מחיקת תצורה נוכחית",
    "Host" : "מארח",
    "You can omit the protocol, unless you require SSL. If so, start with ldaps://" : "ניתן להשמיט את הפרוטוקול, אלא אם כן צריך SSL. אם זה המצב, יש להתחיל ב־ldaps://‎",
    "Port" : "פורט",
    "Detect Port" : "מחיקת שער - פורט",
    "User DN" : "DN משתמש",
    "The DN of the client user with which the bind shall be done, e.g. uid=agent,dc=example,dc=com. For anonymous access, leave DN and Password empty." : "ה- DN של משתמש הלקוח שבו החיבור יעשה, למשל uid=agent,dc=example,dc=com. לחיבור אנונימי, יש להשאיר את ה- DN והסיסמא ריקים.",
    "Password" : "סיסמא",
    "For anonymous access, leave DN and Password empty." : "לגישה אנונימית, השאר את הDM והסיסמא ריקים.",
    "Save Credentials" : "שמירת פרטי הגישה",
    "One Base DN per line" : "DN בסיסי אחד לשורה",
    "You can specify Base DN for users and groups in the Advanced tab" : "ניתן לציין DN בסיסי למשתמשים ולקבוצות בלשונית מתקדם",
    "Detect Base DN" : "גילוי DN בסיסי",
    "Test Base DN" : "בדיקת DN בסיסי",
    "Avoids automatic LDAP requests. Better for bigger setups, but requires some LDAP knowledge." : "נמנע מבקשות אוטומטיות של LDAP. מועדף עבור התקנות גדולות, אבל מחייב ידע מסויים של LDAP.",
    "Manually enter LDAP filters (recommended for large directories)" : "הכנסת מסנני LDAP ידנית (מומלץ עבוק תיקיות גדולות)",
    "The filter specifies which LDAP users shall have access to the %s instance." : "הסינון קובע לאיזו משתמשי LDAP תהיה יכולת כניסה למקרה %s.",
    "Verify settings and count users" : "מאמת הגדרות וסופר משתמשים",
    "Saving" : "שמירה",
    "Back" : "אחורה",
    "Continue" : "המשך",
    "Please renew your password." : "נא לחדש את הססמה שלך.",
    "An internal error occurred." : "אירעה שגיאה פנימית.",
    "Please try again or contact your administrator." : "נא לנסות ליצור קשר עם מנהל המערכת.",
    "Current password" : "ססמה נוכחית",
    "New password" : "ססמה חדשה",
    "Renew password" : "חידוש ססמה",
    "Wrong password." : "ססמה שגויה.",
    "Cancel" : "ביטול",
    "Server" : "שרת",
    "Users" : "משתמשים",
    "Login Attributes" : "פרטי כניסה",
    "Groups" : "קבוצות",
    "Expert" : "מומחה",
    "Advanced" : "מתקדם",
    "<b>Warning:</b> The PHP LDAP module is not installed, the backend will not work. Please ask your system administrator to install it." : "<b>אזהרה:</b> מודול PHP LDAP אינו מותקן, צד אחורי לא יעבוד. יש לבקש מהמנהל המערכת להתקין אותו.",
    "Connection Settings" : "הגדרות התחברות",
    "Configuration Active" : "תצורה פעילה",
    "When unchecked, this configuration will be skipped." : "כאשר לא מסומן, נדלג על תצורה זו.",
    "Backup (Replica) Host" : "גיבוי (העתק) שרת",
    "Give an optional backup host. It must be a replica of the main LDAP/AD server." : "יוצר מארח גיבוי אופציונלי. זה חייב להיות העתק של שרת LDAP/AD עיקרי.",
    "Backup (Replica) Port" : "גיבוי (העתק) שער - פורט",
    "Disable Main Server" : "ניטרול שרת עיקרי",
    "Only connect to the replica server." : "חיבור רק להעתק שרת.",
    "Turn off SSL certificate validation." : "כיבוי אימות אישורי אבטחה SSL.",
    "Not recommended, use it for testing only! If connection only works with this option, import the LDAP server's SSL certificate in your %s server." : "אינו מומלץ, לשימוש לניסיון בלבד! אם החיבור עובד רק עם אפשרות זו, יבוא של תעודת SSL של שרת LDAP בשרת %s שלך.",
    "Cache Time-To-Live" : "מטמון זמן חיים - TTL",
    "in seconds. A change empties the cache." : "בשניות. שינוי מרוקן את המטמון.",
    "Directory Settings" : "הגדרות תיקייה",
    "User Display Name Field" : "שדה שם תצוגה למשתמש",
    "The LDAP attribute to use to generate the user's display name." : "תכונת LDAP לשימוש כדי להפיק את שם התצוגה של המשתמש.",
    "2nd User Display Name Field" : "שדה שני לשם תצוגת משתמש",
    "Optional. An LDAP attribute to be added to the display name in brackets. Results in e.g. »John Doe (john.doe@example.org)«." : "רשות. מאפיין LDAP שיתווסף לשם התצוגה בסוגריים. יגרום למשהו כמו: „ישראל ישראלי (israel@israeli.org)”.",
    "Base User Tree" : "עץ משתמש בסיסי",
    "One User Base DN per line" : "משתמש DN בסיסי אחד לשורה",
    "User Search Attributes" : "מאפייני חיפוש משתמש",
    "Optional; one attribute per line" : "אופציונאלי; מאפיין אחד בשורה",
    "Group Display Name Field" : "שדה שם תצוגה לקבוצה",
    "The LDAP attribute to use to generate the groups's display name." : "מאפיין ה־LDAP בו להשתמש כדי לייצר את שם התצוגה של הקבוצה.",
    "Base Group Tree" : "עץ קבוצה בסיסי",
    "One Group Base DN per line" : "קבוצת DN בסיסית לשורה",
    "Group Search Attributes" : "מאפייני חיפוש קבוצה",
    "Group-Member association" : "שיוך חברי-קבוצה",
    "Dynamic Group Member URL" : "נתיב חבר קבוצה דינמית",
    "Nested Groups" : "קבוצות משנה",
    "Paging chunksize" : "Paging chunksize",
    "Chunksize used for paged LDAP searches that may return bulky results like user or group enumeration. (Setting it 0 disables paged LDAP searches in those situations.)" : "Chunksize משמש לחיפושי paged LDAP שעלולים להחזיר תוצאות גסות כמו ספירת משתמש או קבוצה. (הגדרה כ- 0 מנטרל חיפושי paged LDAP במצבים אלה.)",
    "Enable LDAP password changes per user" : "הפעלת החלפות ססמה ב־LDAP לפי משתמש",
    "(New password is sent as plain text to LDAP)" : "(הססמה החדשה נשלחת כטקסט בלתי מוצפן ל־LDAP)",
    "Special Attributes" : "מאפיינים מיוחדים",
    "Quota Field" : "שדה מכסה",
    "Quota Default" : "ברירת מחדל מכסה",
    "Email Field" : "שדה דואר אלקטרוני",
    "User Home Folder Naming Rule" : "כלל קביעת שם תיקיית בית למשתמש",
    "Internal Username" : "שם משתמש פנימי",
    "Internal Username Attribute:" : "מאפיין שם משתמש פנימי:",
    "Override UUID detection" : "דריסת זיהוי UUID",
    "UUID Attribute for Users:" : "מאפייני UUID למשתמשים:",
    "UUID Attribute for Groups:" : "מאפייני UUID לקבוצות:",
    "Username-LDAP User Mapping" : "מיפוי שם משתמש LDAP:",
    "Clear Username-LDAP User Mapping" : "ניקוי מיפוי שם משתמש LDAP:",
    "Clear Groupname-LDAP Group Mapping" : "ניקוי מיפוי שם משתמש קבוצה LDAP:",
    "Invalid configuration. Please have a look at the logs for further details." : "תצורה שגויה. נא לעיין ברישום לקבלת פרטים נוספים."
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/user_ldap/l10n/he.js <==
OC.L10N.register(
    "user_ldap",
    {
    "Valid configuration, but binding failed. Please check the server settings and credentials." : "התצורה תקפה, אך האיגוד נכשל. נא לבדוק את הגדרות השרת ואת פרטי הגישה.",
    "Invalid configuration: Anonymous binding is not allowed." : "תצורה שגויה: איגוד אלמוני אסור.",
    "Valid configuration, connection established!" : "התצורה תקפה, התבצע חיבור!",
    "Please login with the new password" : "נא להיכנס עם הססמה החדשה",
    "Failed to clear the mappings." : "כשל בניקוי המיפויים.",
    "Your password will expire tomorrow." : "הססמה שלך תפוג מחר.",
    "Your password will expire today." : "הססמה שלך תפוג היום.",
    "_Your password will expire within %n day._::_Your password will expire within %n days._" : ["הססמה שלך תפוג בעוד יום.","הססמה שלך תפוג בעוד יומיים.","הססמה שלך תפוג בעוד %n ימים."],
    "Could not detect user display name attribute. Please specify it yourself in advanced LDAP settings." : "לא ניתן לאתר את מאפיין שם תצוגת המשתמש. נא לציין אותו בעצמך בהגדרות ה־LDAP המתקדמות.",
    "Could not find the desired feature" : "לא אותרה התכונה הרצויה",
    "Invalid Host" : "מארח לא חוקי",
    "LDAP user and group backend" : "מנגנון משתמשים וקבוצות מול LDAP",
    "This application enables administrators to connect Nextcloud to an LDAP-based user directory." : "יישומון זה מאפשר למנהלים להתחבר את Nextcloud לספריית משתמשים מבוססת LDAP.",
    "Connection Settings" : "הגדרות התחברות",
    "Backup (Replica) Host" : "גיבוי (העתק) שרת",
    "Give an optional backup host. It must be a replica of the main LDAP/AD server." : "יוצר מארח גיבוי אופציונלי. זה חייב להיות העתק של שרת LDAP/AD עיקרי.",
    "Backup (Replica) Port" : "גיבוי (העתק) שער - פורט",
    "Only connect to the replica server." : "חיבור רק להעתק שרת.",
    "Disable Main Server" : "ניטרול שרת עיקרי",
    "Turn off SSL certificate validation." : "כיבוי אימות אישורי אבטחה SSL.",
    "Cache Time-To-Live" : "מטמון זמן חיים - TTL",
    "in seconds. A change empties the cache." : "בשניות. שינוי מרוקן את המטמון.",
    "Directory Settings" : "הגדרות תיקייה",
    "User Display Name Field" : "שדה שם תצוגה למשתמש",
    "The LDAP attribute to use to generate the user's display name." : "תכונת LDAP לשימוש כדי להפיק את שם התצוגה של המשתמש.",
    "2nd User Display Name Field" : "שדה שני לשם תצוגת משתמש",
    "Optional. An LDAP attribute to be added to the display name in brackets. Results in e.g. »John Doe (john.doe@example.org)«." : "רשות. מאפיין LDAP שיתווסף לשם התצוגה בסוגריים. יגרום למשהו כמו: „ישראל ישראלי (israel@israeli.org)”.",
    "One User Base DN per line" : "משתמש DN בסיסי אחד לשורה",
    "Base User Tree" : "עץ משתמש בסיסי",
    "Optional; one attribute per line" : "אופציונאלי; מאפיין אחד בשורה",
    "User Search Attributes" : "מאפייני חיפוש משתמש",
    "Group Display Name Field" : "שדה שם תצוגה לקבוצה",
    "The LDAP attribute to use to generate the groups's display name." : "מאפיין ה־LDAP בו להשתמש כדי לייצר את שם התצוגה של הקבוצה.",
    "One Group Base DN per line" : "קבוצת DN בסיסית לשורה",
    "Base Group Tree" : "עץ קבוצה בסיסי",
    "Group Search Attributes" : "מאפייני חיפוש קבוצה",
    "Group-Member association" : "שיוך חברי-קבוצה",
    "Dynamic Group Member URL" : "נתיב חבר קבוצה דינמית",
    "Nested Groups" : "קבוצות משנה",
    "Paging chunksize" : "Paging chunksize",
    "Chunksize used for paged LDAP searches that may return bulky results like user or group enumeration. (Setting it 0 disables paged LDAP searches in those situations.)" : "Chunksize משמש לחיפושי paged LDAP שעלולים להחזיר תוצאות גסות כמו ספירת משתמש או קבוצה. (הגדרה כ- 0 מנטרל חיפושי paged LDAP במצבים אלה.)",
    "Enable LDAP password changes per user" : "הפעלת החלפות ססמה ב־LDAP לפי משתמש",
    "(New password is sent as plain text to LDAP)" : "(הססמה החדשה נשלחת כטקסט בלתי מוצפן ל־LDAP)",
    "Special Attributes" : "מאפיינים מיוחדים",
    "Quota Field" : "שדה מכסה",
    "Quota Default" : "ברירת מחדל מכסה",
    "Email Field" : "שדה דואר אלקטרוני",
    "User Home Folder Naming Rule" : "כלל קביעת שם תיקיית בית למשתמש",
    "Internal Username" : "שם משתמש פנימי",
    "Internal Username Attribute:" : "מאפיין שם משתמש פנימי:",
    "Override UUID detection" : "דריסת זיהוי UUID",
    "Only these object classes:" : "מחלקות עצמים אלו בלבד:",
    "Only from these groups:" : "רק מקבוצות אלו:",
    "Edit LDAP Query" : "עריכת שאילתת LDAP",
    "LDAP Filter:" : "מסנן LDAP:",
    "Verify settings and count the groups" : "אימות ההגדרות וספירת הקבוצות",
    "User found and settings verified." : "משתמש אותר והגדרות אומתו.",
    "Consider narrowing your search, as it encompassed many users, only the first one of whom will be able to log in." : "מוטב לשקול לצמצם את החיפוש שלך, כיוון שהוא מאגד בתוכו משתמשים רבים, רק הראשון מביניהם יוכל להיכנס.",
    "An unspecified error occurred. Please check log and settings." : "אירעה שגיאה בלתי מוגדרת. נא לבדוק את יומן הרישום וההגדרות.",
    "The search filter is invalid, probably due to syntax issues like uneven number of opened and closed brackets. Please revise." : "סינון החיפוש אינו חוקי. ככל הנראה בשל שיאה תחבירית כגון מספר לא שווה של פתח-סוגריים וסגור-סוגריים. יש לתקן.",
    "Other Attributes:" : "מאפיינים נוספים:",
    "Verify settings" : "מאמת הגדרות",
    "No object found in the given Base DN. Please revise." : "לא אותר אוביקט בבסיס DN שסופק. יש להחליף.",
    "More than 1,000 directory entries available." : "קיימים יותר מ- 1,000 רשומות ספריה.",
    "When unchecked, this configuration will be skipped." : "כאשר לא מסומן, נדלג על תצורה זו.",
    "Copy current configuration into new directory binding" : "מעתיק תצורה נוכחית אל תוך תיקייה חדשה",
    "You can omit the protocol, unless you require SSL. If so, start with ldaps://" : "ניתן להשמיט את הפרוטוקול, אלא אם כן צריך SSL. אם זה המצב, יש להתחיל ב־ldaps://‎",
    "Host" : "מארח",
    "Port" : "פורט",
    "Detect Port" : "מחיקת שער - פורט",
    "User DN" : "DN משתמש",
    "For anonymous access, leave DN and Password empty." : "לגישה אנונימית, השאר את הDM והסיסמא ריקים.",
    "Password" : "סיסמא",
    "One Base DN per line" : "DN בסיסי אחד לשורה",
    "You can specify Base DN for users and groups in the Advanced tab" : "ניתן לציין DN בסיסי למשתמשים ולקבוצות בלשונית מתקדם",
    "Detect Base DN" : "גילוי DN בסיסי",
    "Test Base DN" : "בדיקת DN בסיסי",
    "Verify settings and count users" : "מאמת הגדרות וסופר משתמשים",
    "Test Configuration" : "בדיקת הגדרות",
    "Help" : "עזרה",
    "Server" : "שרת",
    "Users" : "משתמשים",
    "Login Attributes" : "פרטי כניסה",
    "Groups" : "קבוצות",
    "Advanced" : "מתקדם",
    "Expert" : "מומחה",
    "Username-LDAP User Mapping" : "מיפוי שם משתמש LDAP:",
    "Clear Username-LDAP User Mapping" : "ניקוי מיפוי שם משתמש LDAP:",
    "Clear Groupname-LDAP Group Mapping" : "ניקוי מיפוי שם משתמש קבוצה LDAP:",
    "An internal error occurred." : "אירעה שגיאה פנימית.",
    "Please try again or contact your administrator." : "נא לנסות ליצור קשר עם מנהל המערכת.",
    "Wrong password." : "ססמה שגויה.",
    "Current password" : "ססמה נוכחית",
    "New password" : "ססמה חדשה",
    "Cancel" : "ביטול",
    "Renew password" : "חידוש ססמה",
    "An error occurred" : "אירעה שגיאה",
    "Mode switch" : "שינוי מצב",
    "Switching the mode will enable automatic LDAP queries. Depending on your LDAP size they may take a while. Do you still want to switch the mode?" : "שינוי המצב יאפשר שאילתות LDAP אוטמטיות. בהתאם לגודל ה- LDAP שלך ייתכן והפעולה תיקח זמן רב. האם ברצונך לשנות את המצב?",
    "Confirm" : "אישור",
    "Failed to delete the server configuration" : "כשל במחיקת הגדרות השרת",
    "Invalid configuration. Please have a look at the logs for further details." : "תצורה שגויה. נא לעיין ברישום לקבלת פרטים נוספים.",
    "No action specified" : "לא צויינה פעולה",
    "No configuration specified" : "לא הוגדרה תצורה",
    "No data specified" : "לא הוגדר מידע",
    "Action does not exist" : "פעולה לא קיימת",
    "Renewing …" : "מתבצע חידוש…",
    "Very weak password" : "ססמה חלשה מאוד",
    "Weak password" : "ססמה חלשה",
    "So-so password" : "ססמה בסדר",
    "Good password" : "ססמה טובה",
    "Strong password" : "ססמה חזקה",
    "The Base DN appears to be wrong" : "בסיס DN נראה כשגוי",
    "Testing configuration…" : "בדיקת תצורה...",
    "Configuration incorrect" : "הגדרה שגויה",
    "Configuration incomplete" : "הגדרה לא מלאה",
    "Configuration OK" : "הגדרה בסדר",
    "Select groups" : "בחירת קבוצות",
    "Select object classes" : "בחירת מחלקות עצמים",
    "Please check the credentials, they seem to be wrong." : "יש לבדוק את פרטי הכניסה, נראה שהם שגויים",
    "Please specify the port, it could not be auto-detected." : "יש לספק את שער הכניסה - פורט, לא ניתן היה לאתרו בצורה אוטומטית",
    "Base DN could not be auto-detected, please revise credentials, host and port." : "לא ניתן היה לאתר באופן אוטומטי את בסיס DN, יש להחליף את פרטי הכניסה, פרטי שרת ושער גישה - פורט.",
    "Could not detect Base DN, please enter it manually." : "לא ניתן היה לאתר את בסיס DN, יש להכניסו באופן ידני.",
    "{nthServer}. Server" : "{nthServer}. שרת",
    "An error occurred. Please check the Base DN, as well as connection settings and credentials." : "אירעה שגיאה. יש לבדוק את בסיס ה- DN, כמו גם את הגדרות החיבור ופרטי הכניסה.",
    "Do you really want to delete the current Server Configuration?" : "האם אכן למחוק את הגדרות השרת הנוכחיות?האם באמת ברצונך למחוק את הגדרות השרת הנוכחיות?",
    "Confirm Deletion" : "אישור המחיקה",
    "Mappings cleared successfully!" : "מיפויים נוקו בהצלחה!",
    "Error while clearing the mappings." : "שגיאה בזמן ניקוי המיפויים.",
    "Anonymous bind is not allowed. Please provide a User DN and Password." : "קישור אננונימי אינו מותר. יש לספק שם משתמש DN וסיסמא.",
    "LDAP Operations error. Anonymous bind might not be allowed." : "שגיאת פעילויות LDAP. יתכן שקישור אנונימי אינו מותר.",
    "Saving failed. Please make sure the database is in Operation. Reload before continuing." : "שמירה נכשלה. יש לבדוק אם מסד הנתונים פעיל. יש לטעון מחדש לפני המשך.",
    "Select attributes" : "בחירת מאפיינים",
    "Please provide a login name to test against" : "יש לספק שם משתמש לבדיקה מולו",
    "Groups meeting these criteria are available in %s:" : "קבוצות העומדות בקריטריון זה זמינות ב- %s:",
    "Search groups" : "חיפוש בקבוצות",
    "Available groups" : "קבוצות זמינות",
    "Selected groups" : "קבוצות נבחרות",
    "The filter specifies which LDAP groups shall have access to the %s instance." : "המסנן הקובע לאיזו קבוצת LDAP תהיה יכולת כניסה למקרה %s.",
    "When logging in, %s will find the user based on the following attributes:" : "כאשר מתחברים, %s יחפש את המשתמש על פי המאפיינים הבאים:",
    "Test Loginname" : "בדיקת שם התחברות",
    "%s. Server:" : "%s. שרת:",
    "Add a new configuration" : "הוספת תצורה חדשה",
    "Delete the current configuration" : "מחיקת תצורה נוכחית",
    "The DN of the client user with which the bind shall be done, e.g. uid=agent,dc=example,dc=com. For anonymous access, leave DN and Password empty." : "ה- DN של משתמש הלקוח שבו החיבור יעשה, למשל uid=agent,dc=example,dc=com. לחיבור אנונימי, יש להשאיר את ה- DN והסיסמא ריקים.",
    "Save Credentials" : "שמירת פרטי הגישה",
    "Avoids automatic LDAP requests. Better for bigger setups, but requires some LDAP knowledge." : "נמנע מבקשות אוטומטיות של LDAP. מועדף עבור התקנות גדולות, אבל מחייב ידע מסויים של LDAP.",
    "Manually enter LDAP filters (recommended for large directories)" : "הכנסת מסנני LDAP ידנית (מומלץ עבוק תיקיות גדולות)",
    "The filter specifies which LDAP users shall have access to the %s instance." : "הסינון קובע לאיזו משתמשי LDAP תהיה יכולת כניסה למקרה %s.",
    "Saving" : "שמירה",
    "Back" : "אחורה",
    "Continue" : "המשך",
    "Please renew your password." : "נא לחדש את הססמה שלך.",
    "<b>Warning:</b> The PHP LDAP module is not installed, the backend will not work. Please ask your system administrator to install it." : "<b>אזהרה:</b> מודול PHP LDAP אינו מותקן, צד אחורי לא יעבוד. יש לבקש מהמנהל המערכת להתקין אותו.",
    "Configuration Active" : "תצורה פעילה",
    "Not recommended, use it for testing only! If connection only works with this option, import the LDAP server's SSL certificate in your %s server." : "אינו מומלץ, לשימוש לניסיון בלבד! אם החיבור עובד רק עם אפשרות זו, יבוא של תעודת SSL של שרת LDAP בשרת %s שלך.",
    "UUID Attribute for Users:" : "מאפייני UUID למשתמשים:",
    "UUID Attribute for Groups:" : "מאפייני UUID לקבוצות:"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
